"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const utils_1 = require("../utils");
const usePrimaryColorStyles = (primaryColor) => {
    const memoizedPrimaryColorStyles = (0, react_1.useMemo)(() => {
        var _a;
        let primaryColorStyles = {
            '--primary-color-h': '227',
            '--primary-color-s': '70%',
            '--primary-color-l': '46%',
        };
        if (primaryColor) {
            // Extract r, g, b values from the string. (r), (g), (b)
            const rgbRegex = /^\s*\(?(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\)?/;
            const rgbMatch = (_a = primaryColor.trim().match(rgbRegex)) === null || _a === void 0 ? void 0 : _a.slice(1);
            if (rgbMatch && rgbMatch.length === 3) {
                const [r, g, b] = rgbMatch;
                const [h, s, l] = (0, utils_1.rgbToHsl)(Number(r), Number(g), Number(b));
                primaryColorStyles = {
                    '--primary-color-h': `${h}`,
                    '--primary-color-s': `${s}%`,
                    '--primary-color-l': `${l}%`,
                };
            }
        }
        return primaryColorStyles;
    }, [primaryColor]);
    return memoizedPrimaryColorStyles;
};
exports.default = usePrimaryColorStyles;
