"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const actions_1 = require("../../components/CioQuiz/actions");
// eslint-disable-next-line max-params
function useSelectInputProps(quizAnswerChanged, nextQuestion, currentQuestionData, answerInputs) {
    var _a;
    const type = currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.type;
    const hasImages = (_a = currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.options) === null || _a === void 0 ? void 0 : _a.some((option) => option.images);
    const [selected, setSelected] = (0, react_1.useState)({});
    const singleSelectClicked = (0, react_1.useRef)({});
    const toggleIdSelected = (0, react_1.useCallback)((id) => {
        if (type === actions_1.QuestionTypes.SingleSelect) {
            singleSelectClicked.current = true;
            setSelected({ [id]: true });
        }
        else if (type === actions_1.QuestionTypes.MultipleSelect) {
            if (selected[id]) {
                const newState = Object.assign({}, selected);
                delete newState[id];
                setSelected(newState);
            }
            else {
                setSelected(Object.assign(Object.assign({}, selected), { [id]: true }));
            }
        }
    }, [selected, type]);
    const onOptionKeyDown = (event, id) => {
        if ((event === null || event === void 0 ? void 0 : event.key) === ' ' || (event === null || event === void 0 ? void 0 : event.key) === 'Enter') {
            toggleIdSelected(id);
        }
    };
    // Update component local state
    (0, react_1.useEffect)(() => {
        var _a;
        if (currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.type) {
            const nextQuestionId = currentQuestionData.id;
            const currentAnswer = answerInputs === null || answerInputs === void 0 ? void 0 : answerInputs[nextQuestionId];
            const prevSelected = {};
            if (Array.isArray(currentAnswer === null || currentAnswer === void 0 ? void 0 : currentAnswer.value)) {
                (_a = currentAnswer === null || currentAnswer === void 0 ? void 0 : currentAnswer.value) === null || _a === void 0 ? void 0 : _a.forEach((answer) => {
                    prevSelected[Number(answer)] = true;
                    setSelected(prevSelected);
                });
            }
        }
        singleSelectClicked.current = false;
        return function clearState() {
            setSelected({});
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.id]);
    // Update global state
    (0, react_1.useEffect)(() => {
        if ((currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.type) === 'multiple' || (currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.type) === 'single') {
            const selectedAnswers = Object.keys(selected).filter((key) => selected[Number(key)]);
            quizAnswerChanged(selectedAnswers);
        }
    }, [selected, currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.id, currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.type, quizAnswerChanged]);
    // Go to next question only every time answerInputs (answers input state) changes...
    // and it's a singleSelectQuestion and user has just clicked on an option
    (0, react_1.useEffect)(() => {
        if ((currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.type) === 'single' && singleSelectClicked.current) {
            nextQuestion();
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [answerInputs]);
    const getSelectInputProps = (0, react_1.useCallback)((option) => ({
        className: `${!hasImages ? 'cio-question-option-container-text-only' : 'cio-question-option-container'} ${selected[option.id] ? 'selected' : ''}`,
        onClick: () => {
            toggleIdSelected(option.id);
        },
        onKeyDown: (event) => {
            onOptionKeyDown(event, option.id);
        },
        role: 'button',
        tabIndex: 0,
        key: option.id,
    }), 
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [currentQuestionData === null || currentQuestionData === void 0 ? void 0 : currentQuestionData.id, selected]);
    return getSelectInputProps;
}
exports.default = useSelectInputProps;
